use std::path::PathBuf;
use structopt::StructOpt;

#[derive(Clone, StructOpt)]
pub struct AppArgs {
    #[structopt(short = "c", long = "ctx", default_value = "debug")]
    pub context: String,

    #[structopt(short = "d", long = "dir")]
    pub app_storage_root: Option<PathBuf>,

    #[structopt(long)]
    pub load: Option<PathBuf>,

    #[structopt(short, long, default_value = "localhost")]
    pub host: String,

    #[structopt(short, long, default_value = "8080")]
    pub port: u16,

    #[structopt(long = "ptls", default_value = "8443")]
    pub port_tls: u16,

    #[structopt(long = "certs_dir", default_value = "/etc/letsencrypt/live")]
    pub ssl_certs_dir: PathBuf,

    #[structopt(long = "adm", default_value = "admin")]
    pub admin_username: String,

    #[structopt(long = "pwd", default_value = "password")]
    pub admin_pwd: String,

    #[structopt(long = "admin_cookie_name", default_value = "krustacea_admin_auth")]
    pub admin_cookie_name: String,
}

impl AppArgs {
    #[cfg(test)]
    pub fn testing() -> Self {
        AppArgs {
            context: String::from("debug"),
            app_storage_root: None,
            load: None,
            host: String::from("localhost"),
            port: 8080,
            port_tls: 8443,
            ssl_certs_dir: PathBuf::from("/etc/letsencrypt/live"),
            admin_username: String::from("admin"),
            admin_pwd: String::from("password"),
            admin_cookie_name: String::from("krustacea_admin_auth"),
        }
    }
}
